@@ -14,6 +14,8 @@ class AgentType(str, Enum):
     NOT_SELECTED = "not_selected"
     CURSOR = "cursor"
     CLAUDE = "claude"
+    CODEX = "codex"
+    OPENCODE = "opencode"
 
     @classmethod
     def list(cls) -> List['AgentType']:
@@ -32,6 +34,10 @@ class AgentType(str, Enum):
             return "Cursor"
         elif self == AgentType.CLAUDE:
             return "Claude Code"
+        elif self == AgentType.CODEX:
+            return "Codex"
+        elif self == AgentType.OPENCODE:
+            return "OpenCode"
         return self.value.title()
 
 
